==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+105"/>
        <source>Files</source>
        <translation>Archivos</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Exportar mapa de bits</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>Error al generar el archivo de mapa de bits &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>Archivo de mapa de bits se ha exportado en &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while generating Bitmap file &quot;%1&quot;: %2</source>
        <translation type="obsolete">Error al generar el archivo de mapa de bits &quot;%1&quot;: &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Bitmap file has been exported to &quot;%1&quot;</source>
        <translation type="obsolete">Archivo de mapa de bits se ha exportado en &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;Exportar mapa de bits...</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Exportar mapa de bits</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Anchura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Píxeles por unidad de dibujo:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>Márgen:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>Fondo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Blanco</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Negro</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/BitmapExport/ts/BitmapExport_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+119"/>
        <source>Files</source>
        <translation>Archivos</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Exportar mapa de bits</translation>
    </message>
    <message>
        <location line="-51"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>Error al generar el archivo de mapa de bits &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>Archivo de mapa de bits se ha exportado en &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while generating Bitmap file &quot;%1&quot;: %2</source>
        <translation type="obsolete">Error al generar el archivo de mapa de bits &quot;%1&quot;: &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Bitmap file has been exported to &quot;%1&quot;</source>
        <translation type="obsolete">Archivo de mapa de bits se ha exportado en &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;Exportar mapa de bits...</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Exportar mapa de bits</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Anchura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Píxeles por unidad de dibujo:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Export bounding box of selection</source>
        <translation>Exportar área rectangular alrededor de la selección</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Transparent</source>
        <translation>Transparente</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+23"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Monochrome</source>
        <translation>Monocromo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Grayscale</source>
        <translation>Escala de grises</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Anti-aliasing</source>
        <translation>Antialiasing</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use anti-aliasing</source>
        <translation>Antialiasing</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Margin</source>
        <translation>Márgen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin:</source>
        <translation>Márgen:</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add extra margin to compensate for line weight</source>
        <translation>Agregue un margen adicional para compensar el peso de la línea</translation>
    </message>
    <message>
        <location line="-170"/>
        <source>Background</source>
        <translation>Fondo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Blanco</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Negro</translation>
    </message>
</context>
<context>
    <name>BitmapExportWorker</name>
    <message>
        <location filename="../BitmapExportWorker.js" line="+106"/>
        <source>Invalid image size (width x height must be less than %1)</source>
        <translation>Tamaño de imagen no válido (anchura x altura debe ser menor que %1)</translation>
    </message>
</context>
</TS>
